RigolDSA - Heros Devices 0.6.1 documentation

Skip to content
Back to top
View this page

# RigolDSA

From: Rigol Technologies

Class: `herosdevices.hardware.rigol.RigolDSA`

Driver Quality Index: beta

A class to interface Rigol digital spectrum analyzers.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.rigol.RigolDSA` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  | Address or IP of the instrument.

This JSON string can be used to start a HERO device representation of `RigolDSA` using BOSS.

    {
        "_id": "my_RigolDSA",
        "classname": "herosdevices.hardware.rigol.RigolDSA",
        "arguments": {
            "address": "<class 'str'>"
        }
    }